""" This module provide functions to convert a PDF to text """


class Converter:
    """ A simple convertor for converting PDFs to text. """

    def convert(self, path):
        """ 
        Convert the given PDF to text.

        Parameters:
        path (str): The path to the PDF file.

        Returns:
        str: The content of the PDF file as text. 
        """
        print("pdf2text")
